==> weblog-1_10.tar.gz: weblog/language/japanese/modinfo.php <==
<?php
/**
 * $Id: modinfo.php,v 1.1 2003/08/29 13:43:58 wellwine Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
/*
 * version j0.90 2003/05/18 JST
 * Traslated into Japanese by wellwine (http://wellwine.zive.net)
 * Copyright (c) 2003 by wellwine
 *
 * version j0.91 2003/05/19 JST
 */

define('_MI_WEBLOG_NAME','֥');
define('_MI_WEBLOG_DESC','֥/㡼ʥ륷ƥ');
define('_MI_WEBLOG_SMNAME1','ޥ֥');
define('_MI_WEBLOG_SMNAME2','֥');
define('_MI_WEBLOG_SMNAME3','');

define('_MI_WEBLOG_NOTIFY','ɽΥ֥');
define('_MI_WEBLOG_NOTIFYDSC','Υ֥ѹäΤ');
define('_MI_WEBLOG_ENTRY_NOTIFY','ɽΥ֥ȥ');
define('_MI_WEBLOG_ENTRY_NOTIFYDSC','Υ֥ȥѹäΤ');

define('_MI_WEBLOG_ADD_NOTIFY','');
define('_MI_WEBLOG_ADD_NOTIFYCAP','ȥ꤬Ƥ줿Τ');
define('_MI_WEBLOG_ADD_NOTIFYDSC','ȥ꤬Ƥ줿Ȥ');
define('_MI_WEBLOG_ADD_NOTIFYSBJ','֥');

define('_MI_WEBLOG_ENTRY_COMMENT','ɲä줿');
define('_MI_WEBLOG_ENTRY_COMMENTDSC','Υȥ˿ȤƤ줿Τ');

define('_MI_WEBLOG_RECENT_BNAME1','ǿ֥ȥ');
define('_MI_WEBLOG_RECENT_BNAME1_DESC','ǿ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS','ȥåץ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS_DESC','äȤɤޤƤ֥ȥ');

// Config Settings
define('_MI_WEBLOG_NUMPERPAGE','ڡɽ륨ȥ');
define('_MI_WEBLOG_NUMPERPAGEDSC','');
define('_MI_WEBLOG_NUMINRECENTBLOCK','ǿ֥֥åɽ륨ȥ');
define('_MI_WEBLOG_NUMINRECENTBLOCKDSC','');
define('_MI_WEBLOG_DATEFORMAT','ս');
define('_MI_WEBLOG_DATEFORMATDSC','');
define('_MI_WEBLOG_TIMEFORMAT','');
define('_MI_WEBLOG_TIMEFORMATDSC','');
define('_MI_WEBLOG_RECENT_DATEFORMAT','ǿȥ֥åս');
define('_MI_WEBLOG_RECENT_DATEFORMATDSC','');
define('_MI_WEBLOG_SHOWAVATAR','ƥȥ˥Хɽ');
define('_MI_WEBLOG_SHOWAVATARDSC','');
define('_MI_WEBLOG_ALIGNAVATAR','Х');
define('_MI_WEBLOG_ALIGNAVATARDSC','');
define('_MI_WEBLOG_MINENTRYSIZE','ȥκ㥵');
define('_MI_WEBLOG_MINENTRYSIZEDSC','0ꤹȥåޤ');

define('_MI_WEBLOG_UPDATE_READS_WHEN','򥫥ȥåפΤ');
define('_MI_WEBLOG_UPDATE_READS_WHENDSC','־ܺ٤줿ȤפǤϾܺٲ̤ǥȥȤ֥桼ΥꥹȤ줿ȤפǤϤ桼ΥȥꥹȥåפȤ֥ꥹȤ줿ȤפǤϤɤʷǤ쥨ȥ꤬ꥹȥåפ줿Ȥ줾ޤ');
define('_MI_WEBLOG_UPDATE_READS_WHEN1','ܺ٤줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN2','桼ΥꥹȤ줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN3','ꥹȤ줿Ȥ');

define('_MI_WEBLOG_TEMPLATE_ENTRIESDSC','ꤵ줿֥Υȥɽ');
define('_MI_WEBLOG_TEMPLATE_POSTDSC','֥ȥƤ');
define('_MI_WEBLOG_TEMPLATE_DETAILSDSC','֥ȥξܺ٤ɽ');
define('_MI_WEBLOG_TEMPLATE_RSSFEEDDSC','ǿȥRSSե');
define('_MI_WEBLOG_TEMPLATE_PRINTDSC','ѥڡ');
define('_MI_WEBLOG_TEMPLATE_ARCHIVEDSC','ȤΥ֥ꥹ');

define('_MI_WEBLOG_EDITORHEIGHT','Խѥƥȥꥢι⤵()');
define('_MI_WEBLOG_EDITORHEIGHTDSC','Խѥƥȥꥢι⤵Կꤷޤ');
define('_MI_WEBLOG_EDITORWIDTH','Խѥƥȥꥢ(ʸ)');
define('_MI_WEBLOG_EDITORWIDTHDSC','Խѥƥȥꥢꤷޤ');
define('_MI_WEBLOG_ONLYADMIN',"ͥ롼ץ桼ΤߤƤǤ");
define('_MI_WEBLOG_ONLYADMINDSC','֤פꤹȤ٤ƤϿ桼ȥƤ뤳ȤǤޤĤޤ֤Ϥפꤹȴͥ롼פΥ桼ƤǤޤ');

// wellwine for read cookie
define('_MI_WEBLOG_EXPIRATION','Ѥߤͭ(ñ:)');
define('_MI_WEBLOG_EXPIRATIONDSC','֥ȥꤴȤαѤͭ¤ꤷƤδ֤᤮Ʊȥȱޤ');
define('_MI_WEBLOG_RSSSHOW','RSSɽ');
define('_MI_WEBLOG_RSSSHOWDSC','');
define('_MI_WEBLOG_RSSMAX','RSS˥եɤ륨ȥ');
define('_MI_WEBLOG_RSSMAXDSC','');
?>

==> weblog-1_20.tar.gz: weblog/language/japanese/modinfo.php <==
<?php
/**
 * $Id: modinfo.php,v 1.3 2003/09/01 15:05:56 wellwine Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
/*
 * version j0.90 2003/05/18 JST
 * Traslated into Japanese by wellwine (http://wellwine.zive.net)
 * Copyright (c) 2003 by wellwine
 *
 * version j0.91 2003/05/19 JST
 */

define('_MI_WEBLOG_NAME','֥');
define('_MI_WEBLOG_DESC','֥/㡼ʥ륷ƥ');
define('_MI_WEBLOG_SMNAME1','ޥ֥');
define('_MI_WEBLOG_SMNAME2','֥');
define('_MI_WEBLOG_SMNAME3','');

// submenu name
define('_MI_WEBLOG_DBMANAGER', 'ǡ١');
define('_MI_WEBLOG_CATMANAGER', 'ƥ');

define('_MI_WEBLOG_NOTIFY','ɽΥ֥');
define('_MI_WEBLOG_NOTIFYDSC','Υ֥ѹäΤ');
define('_MI_WEBLOG_ENTRY_NOTIFY','ɽΥ֥ȥ');
define('_MI_WEBLOG_ENTRY_NOTIFYDSC','Υ֥ȥѹäΤ');

define('_MI_WEBLOG_ADD_NOTIFY','');
define('_MI_WEBLOG_ADD_NOTIFYCAP','ȥ꤬Ƥ줿Τ');
define('_MI_WEBLOG_ADD_NOTIFYDSC','ȥ꤬Ƥ줿Ȥ');
define('_MI_WEBLOG_ADD_NOTIFYSBJ','֥');

define('_MI_WEBLOG_ENTRY_COMMENT','ɲä줿');
define('_MI_WEBLOG_ENTRY_COMMENTDSC','Υȥ˿ȤƤ줿Τ');

define('_MI_WEBLOG_RECENT_BNAME1','ǿ֥ȥ');
define('_MI_WEBLOG_RECENT_BNAME1_DESC','ǿ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS','ȥåץ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS_DESC','äȤɤޤƤ֥ȥ');

// Config Settings
define('_MI_WEBLOG_NUMPERPAGE','ڡɽ륨ȥ');
define('_MI_WEBLOG_NUMPERPAGEDSC','');
define('_MI_WEBLOG_DATEFORMAT','ս');
define('_MI_WEBLOG_DATEFORMATDSC','');
define('_MI_WEBLOG_TIMEFORMAT','');
define('_MI_WEBLOG_TIMEFORMATDSC','');
define('_MI_WEBLOG_RECENT_DATEFORMAT','ǿȥ֥åս');
define('_MI_WEBLOG_RECENT_DATEFORMATDSC','');
define('_MI_WEBLOG_SHOWAVATAR','ƥȥ˥Хɽ');
define('_MI_WEBLOG_SHOWAVATARDSC','');
define('_MI_WEBLOG_ALIGNAVATAR','Х');
define('_MI_WEBLOG_ALIGNAVATARDSC','');
define('_MI_WEBLOG_MINENTRYSIZE','ȥκ㥵');
define('_MI_WEBLOG_MINENTRYSIZEDSC','0ꤹȥåޤ');
define('_MI_WEBLOG_IMGURL', 'URL');
define('_MI_WEBLOG_IMGURLDSC', 'ѥڡRSSɽޤϵҤURLꤷޤ');

define('_MI_WEBLOG_UPDATE_READS_WHEN','򥫥ȥåפΤ');
define('_MI_WEBLOG_UPDATE_READS_WHENDSC','־ܺ٤줿ȤפǤϾܺٲ̤ǥȥȤ֥桼ΥꥹȤ줿ȤפǤϤ桼ΥȥꥹȥåפȤ֥ꥹȤ줿ȤפǤϤɤʷǤ쥨ȥ꤬ꥹȥåפ줿Ȥ줾ޤ');
define('_MI_WEBLOG_UPDATE_READS_WHEN1','ܺ٤줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN2','桼ΥꥹȤ줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN3','ꥹȤ줿Ȥ');

define('_MI_WEBLOG_TEMPLATE_ENTRIESDSC','ꤵ줿֥Υȥɽ');
define('_MI_WEBLOG_TEMPLATE_POSTDSC','֥ȥƤ');
define('_MI_WEBLOG_TEMPLATE_DETAILSDSC','֥ȥξܺ٤ɽ');
define('_MI_WEBLOG_TEMPLATE_RSSFEEDDSC','ǿȥRSSե');
define('_MI_WEBLOG_TEMPLATE_PRINTDSC','ѥڡ');
define('_MI_WEBLOG_TEMPLATE_ARCHIVEDSC','ȤΥ֥ꥹ');

define('_MI_WEBLOG_EDITORHEIGHT','Խѥƥȥꥢι⤵()');
define('_MI_WEBLOG_EDITORHEIGHTDSC','Խѥƥȥꥢι⤵Կꤷޤ');
define('_MI_WEBLOG_EDITORWIDTH','Խѥƥȥꥢ(ʸ)');
define('_MI_WEBLOG_EDITORWIDTHDSC','Խѥƥȥꥢꤷޤ');
define('_MI_WEBLOG_ONLYADMIN',"ͥ롼ץ桼ΤߤƤǤ");
define('_MI_WEBLOG_ONLYADMINDSC','֤פꤹȤ٤ƤϿ桼ȥƤ뤳ȤǤޤĤޤ֤Ϥפꤹȴͥ롼פΥ桼ƤǤޤ');

// wellwine for read cookie
define('_MI_WEBLOG_EXPIRATION','Ѥߤͭ(ñ:)');
define('_MI_WEBLOG_EXPIRATIONDSC','֥ȥꤴȤαѤͭ¤ꤷƤδ֤᤮Ʊȥȱޤ');
define('_MI_WEBLOG_RSSSHOW','RSSɽ');
define('_MI_WEBLOG_RSSSHOWDSC','');
define('_MI_WEBLOG_RSSMAX','RSS˥եɤ륨ȥ');
define('_MI_WEBLOG_RSSMAXDSC','');
?>
